/**
 * Copyright (C) 2014 Shu Ding
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */

'use strict';

/**
 * Extended Euclidean algorithm to calculate the solve of 
 *   ax + by = gcd(a, b)
 * gcd(a, b) is the greatest common divisor of integers a and b.
 *
 * @param Number
 * @param Number
 *
 * @return {Number, Number}
 */
var extEuclid = function (a, b) {
    var s = 0, oldS = 1;
    var t = 1, oldT = 0;
    var r = b, oldR = a;
    var quotient, temp;
    while (r !== 0) {
        quotient = Math.floor(oldR / r);

        temp = r;
        r = oldR - quotient * r;
        oldR = temp;

        temp = s;
        s = oldS - quotient * s;
        oldS = temp;

        temp = t;
        t = oldT - quotient * t;
        oldT = temp;
    }

    return {
        x: oldS,
        y: oldT
    };
};

module.exports = extEuclid;
